@@ -3,25 +3,29 @@ package exec
 import (
 	"bufio"
 	"fmt"
-	"golang.org/x/term"
 	"io"
-	"os"
 	"strings"
 	"sync"
 
-	"github.com/jedib0t/go-pretty/v6/text"
+	"golang.org/x/term"
+
+	"github.com/gookit/color"
 
 	"github.com/alajmo/mani/core"
 	"github.com/alajmo/mani/core/dao"
-	"github.com/alajmo/mani/core/print"
 )
 
-func (exec *Exec) Text(dryRun bool) {
+func (exec *Exec) Text(
+	dryRun bool,
+	stdout io.Writer,
+	stderr io.Writer,
+) {
+	task := exec.Tasks[0]
 	clients := exec.Clients
 
 	prefixMaxLen := calcMaxPrefixLength(clients)
 
-	wg := core.NewSizedWaitGroup(20)
+	wg := core.NewSizedWaitGroup(task.SpecData.Forks)
 	for i, c := range clients {
 		task := exec.Tasks[i]
 		wg.Add()
@@ -29,24 +33,31 @@ func (exec *Exec) Text(dryRun bool) {
 		if task.SpecData.Parallel {
 			go func(i int, c Client, wg *core.SizedWaitGroup) {
 				defer wg.Done()
-				_ = exec.TextWork(i, prefixMaxLen, dryRun)
+				_ = exec.TextWork(i, prefixMaxLen, dryRun, stdout, stderr)
 			}(i, c, &wg)
 		} else {
 			func(i int, c Client, wg *core.SizedWaitGroup) {
 				defer wg.Done()
-				_ = exec.TextWork(i, prefixMaxLen, dryRun)
+				_ = exec.TextWork(i, prefixMaxLen, dryRun, stdout, stderr)
 			}(i, c, &wg)
 		}
 	}
 
 	wg.Wait()
+
+	fmt.Fprintf(stdout, "\n")
 }
 
-func (exec *Exec) TextWork(rIndex int, prefixMaxLen int, dryRun bool) error {
+func (exec *Exec) TextWork(
+	rIndex int,
+	prefixMaxLen int,
+	dryRun bool,
+	stdout io.Writer,
+	stderr io.Writer,
+) error {
 	client := exec.Clients[rIndex]
 	task := exec.Tasks[rIndex]
-
-	prefix := getPrefixer(client, rIndex, prefixMaxLen, task.ThemeData.Text, task.SpecData.Parallel)
+	prefix := getPrefixer(client, rIndex, prefixMaxLen, task.ThemeData.Stream, task.SpecData.Parallel)
 
 	var numTasks int
 	if task.Cmd != "" {
@@ -71,7 +82,11 @@ func (exec *Exec) TextWork(rIndex int, prefixMaxLen int, dryRun bool) error {
 			numTasks: numTasks,
 		}
 
-		err := RunTextCmd(args, task.ThemeData.Text, prefix, task.SpecData.Parallel, &wg)
+		if cmd.TTY {
+			return ExecTTY(cmd.Cmd, cmd.EnvList)
+		}
+
+		err := RunTextCmd(args, task.ThemeData.Stream, prefix, task.SpecData.Parallel, &wg, stdout, stderr)
 		if err != nil && !task.SpecData.IgnoreErrors {
 			return err
 		}
@@ -92,7 +107,11 @@ func (exec *Exec) TextWork(rIndex int, prefixMaxLen int, dryRun bool) error {
 			numTasks: numTasks,
 		}
 
-		err := RunTextCmd(args, task.ThemeData.Text, prefix, task.SpecData.Parallel, &wg)
+		if task.TTY {
+			return ExecTTY(task.Cmd, task.EnvList)
+		}
+
+		err := RunTextCmd(args, task.ThemeData.Stream, prefix, task.SpecData.Parallel, &wg, stdout, stderr)
 		if err != nil && !task.SpecData.IgnoreErrors {
 			return err
 		}
@@ -103,11 +122,19 @@ func (exec *Exec) TextWork(rIndex int, prefixMaxLen int, dryRun bool) error {
 	return nil
 }
 
-func RunTextCmd(t TableCmd, textStyle dao.Text, prefix string, parallel bool, wg *sync.WaitGroup) error {
+func RunTextCmd(
+	t TableCmd,
+	textStyle dao.Stream,
+	prefix string,
+	parallel bool,
+	wg *sync.WaitGroup,
+	stdout io.Writer,
+	stderr io.Writer,
+) error {
 	combinedEnvs := dao.MergeEnvs(t.client.Env, t.env)
 
 	if textStyle.Header && !parallel {
-		printHeader(t.cIndex, t.numTasks, t.name, t.desc, textStyle)
+		printHeader(stdout, t.cIndex, t.numTasks, t.name, t.desc, textStyle)
 	}
 
 	if t.dryRun {
@@ -125,13 +152,13 @@ func RunTextCmd(t TableCmd, textStyle dao.Text, prefix string, parallel bool, wg
 		defer wg.Done()
 		var err error
 		if prefix != "" {
-			_, err = io.Copy(os.Stdout, core.NewPrefixer(client.Stdout(), prefix))
+			_, err = io.Copy(stdout, core.NewPrefixer(client.Stdout(), prefix))
 		} else {
-			_, err = io.Copy(os.Stdout, client.Stdout())
+			_, err = io.Copy(stdout, client.Stdout())
 		}
 
 		if err != nil && err != io.EOF {
-			fmt.Fprintf(os.Stderr, "%v", err)
+			fmt.Fprintf(stderr, "%s", err)
 		}
 	}(t.client)
 	wg.Add(1)
@@ -141,13 +168,13 @@ func RunTextCmd(t TableCmd, textStyle dao.Text, prefix string, parallel bool, wg
 		defer wg.Done()
 		var err error
 		if prefix != "" {
-			_, err = io.Copy(os.Stderr, core.NewPrefixer(client.Stderr(), prefix))
+			_, err = io.Copy(stderr, core.NewPrefixer(client.Stderr(), prefix))
 		} else {
-			_, err = io.Copy(os.Stderr, client.Stderr())
+			_, err = io.Copy(stderr, client.Stderr())
 		}
 
 		if err != nil && err != io.EOF {
-			fmt.Fprintf(os.Stderr, "%v", err)
+			fmt.Fprintf(stderr, "%s", err)
 		}
 	}(t.client)
 	wg.Add(1)
@@ -156,9 +183,9 @@ func RunTextCmd(t TableCmd, textStyle dao.Text, prefix string, parallel bool, wg
 
 	if err := t.client.Wait(); err != nil {
 		if prefix != "" {
-			fmt.Printf("%s%s\n", prefix, err.Error())
+			fmt.Fprintf(stderr, "%s%s\n", prefix, err)
 		} else {
-			fmt.Printf("%s\n", err.Error())
+			fmt.Fprintf(stderr, "%s\n", err)
 		}
 
 		return err
@@ -167,28 +194,29 @@ func RunTextCmd(t TableCmd, textStyle dao.Text, prefix string, parallel bool, wg
 	return nil
 }
 
-func printHeader(i int, numTasks int, name string, desc string, ts dao.Text) {
+// TASK [pwd] -------------
+func printHeader(stdout io.Writer, i int, numTasks int, name string, desc string, ts dao.Stream) {
 	var header string
 
-	var prefixName string
+	prefixName := ""
 	if name == "" {
-		prefixName = "Command"
+		prefixName = color.Bold.Sprint("Command")
 	} else {
-		prefixName = name
+		prefixName = color.Bold.Sprint(name)
 	}
 
 	var prefixPart1 string
 	if numTasks > 1 {
-		prefixPart1 = fmt.Sprintf("%s (%d/%d)", text.Bold.Sprintf(ts.HeaderPrefix), i+1, numTasks)
+		prefixPart1 = fmt.Sprintf("%s (%d/%d)", color.Bold.Sprint(ts.HeaderPrefix), i+1, numTasks)
 	} else {
-		prefixPart1 = text.Bold.Sprintf(ts.HeaderPrefix)
+		prefixPart1 = color.Bold.Sprint(ts.HeaderPrefix)
 	}
 
 	var prefixPart2 string
 	if desc != "" {
-		prefixPart2 = fmt.Sprintf("[%s: %s]", text.Bold.Sprintf(prefixName), desc)
+		prefixPart2 = fmt.Sprintf("[%s: %s]", prefixName, desc)
 	} else {
-		prefixPart2 = fmt.Sprintf("[%s]", text.Bold.Sprintf(prefixName))
+		prefixPart2 = fmt.Sprintf("[%s]", prefixName)
 	}
 
 	width, _, _ := term.GetSize(0)
@@ -201,48 +229,44 @@ func printHeader(i int, numTasks int, name string, desc string, ts dao.Text) {
 	headerLength := len(core.Strip(header))
 
 	if width > 0 && ts.HeaderChar != "" {
-		header = fmt.Sprintf("\n%s %s\n", header, strings.Repeat(ts.HeaderChar, width-headerLength-1))
+		header = fmt.Sprintf("\n%s %s\n\n", header, strings.Repeat(ts.HeaderChar, width-headerLength-1))
 	} else {
-		header = fmt.Sprintf("\n%s\n", header)
+		header = fmt.Sprintf("\n%s\n\n", header)
 	}
-	fmt.Println(header)
+	fmt.Fprint(stdout, header)
 }
 
-func getPrefixer(client Client, i, prefixMaxLen int, textStyle dao.Text, parallel bool) string {
+// mani | /projects/mani
+func getPrefixer(client Client, i, prefixMaxLen int, textStyle dao.Stream, parallel bool) string {
 	if !textStyle.Prefix {
 		return ""
 	}
 
-	prefix := client.Prefix()
-	prefixLen := len(prefix)
-	var prefixColor *text.Color
+	// Project name color
+	var prefixColor color.RGBColor
 	if len(textStyle.PrefixColors) < 1 {
-		prefixColor = print.GetFg("")
+		prefixColor = dao.StyleFg("")
 	} else {
-		prefixColor = print.GetFg(textStyle.PrefixColors[i%len(textStyle.PrefixColors)])
+		fg := textStyle.PrefixColors[i%len(textStyle.PrefixColors)]
+		prefixColor = dao.StyleFg(fg)
 	}
 
+	prefix := client.Prefix()
+	prefixLen := len(prefix)
+	// If we don't have a task header or the execution is parallel, then left pad the prefix.
 	if (!textStyle.Header || parallel) && len(prefix) < prefixMaxLen { // Left padding.
 		prefixString := prefix + strings.Repeat(" ", prefixMaxLen-prefixLen) + " | "
-		if prefixColor != nil {
-			prefix = prefixColor.Sprintf(prefixString)
-		} else {
-			prefix = prefixString
-		}
+		prefix = prefixColor.Sprint(prefixString)
 	} else {
 		prefixString := prefix + " | "
-		if prefixColor != nil {
-			prefix = prefixColor.Sprintf(prefixString)
-		} else {
-			prefix = prefixString
-		}
+		prefix = prefixColor.Sprint(prefixString)
 	}
 
 	return prefix
 }
 
 func calcMaxPrefixLength(clients []Client) int {
-	var prefixMaxLen int = 0
+	var prefixMaxLen = 0
 	for _, c := range clients {
 		prefix := c.Prefix()
 		if len(prefix) > prefixMaxLen {
